@@ -24,9 +24,10 @@
 #include <getopt.h>
 #include <cstdlib>
 #include <unistd.h>
+#include <utility>
+
 #ifdef HAVE_QDBUS
     #include <QtDBus/QtDBus>
-    #include <unistd.h>
     #include "processadaptor.h"
 #endif
 
@@ -40,6 +41,9 @@
 
 const char* const short_options = "vhw:e:dp:";
 
+static const char* serviceName = "org.lxqt.QTerminal";
+static const char* ifaceName = "org.lxqt.QTerminal.Process";
+
 const struct option long_options[] = {
     {"version", 0, nullptr, 'v'},
     {"help",    0, nullptr, 'h'},
@@ -75,7 +79,7 @@ QTerminalApp * QTerminalApp::m_instance = nullptr;
 
 void parse_args(int argc, char* argv[], QString& workdir, QStringList & shell_command, out bool& dropMode)
 {
-    int next_option;
+    int next_option = 0;
     dropMode = false;
     do{
         next_option = getopt_long(argc, argv, short_options, long_options, nullptr);
@@ -133,20 +137,27 @@ int main(int argc, char *argv[])
     QApplication::setApplicationName(QStringLiteral("qterminal"));
     QApplication::setApplicationVersion(QStringLiteral(QTERMINAL_VERSION));
     QApplication::setOrganizationDomain(QStringLiteral("qterminal.org"));
-    QApplication::setDesktopFileName(QLatin1String("qterminal.desktop"));
+    QApplication::setDesktopFileName(QLatin1String("qterminal"));
     // Warning: do not change settings format. It can screw bookmarks later.
     QSettings::setDefaultFormat(QSettings::IniFormat);
 
     QTerminalApp *app = QTerminalApp::Instance(argc, argv);
-    #ifdef HAVE_QDBUS
-        app->registerOnDbus();
-    #endif
 
     QString workdir;
     QStringList shell_command;
-    bool dropMode;
+    bool dropMode = false;
     parse_args(argc, argv, workdir, shell_command, dropMode);
 
+    #ifdef HAVE_QDBUS
+        app->registerOnDbus(dropMode);
+    #endif
+
+    if (!app->isPrimaryInstance())
+    {
+        app->requestDropDown();
+        return 0;
+    }
+
     Properties::Instance()->migrate_settings();
     Properties::Instance()->loadSettings();
 
@@ -169,7 +180,6 @@ int main(int argc, char *argv[])
 
     // icons
     /* setup our custom icon theme if there is no system theme (OS X, Windows) */
-    QCoreApplication::instance()->setAttribute(Qt::AA_UseHighDpiPixmaps); //Fix for High-DPI systems
     if (QIcon::themeName().isEmpty())
         QIcon::setThemeName(QStringLiteral("QTerminal"));
 
@@ -177,26 +187,31 @@ int main(int argc, char *argv[])
 
     // install the translations built-into Qt itself
     QTranslator qtTranslator;
-    qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-    app->installTranslator(&qtTranslator);
+    if (qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::path(QLibraryInfo::TranslationsPath)))
+    {
+        app->installTranslator(&qtTranslator);
+    }
 
     QTranslator translator;
+    bool installTr = false;
     QString fname = QString::fromLatin1("qterminal_%1.qm").arg(QLocale::system().name().left(5));
 #ifdef TRANSLATIONS_DIR
     //qDebug() << "TRANSLATIONS_DIR: Loading translation file" << fname << "from dir" << TRANSLATIONS_DIR;
-    /*qDebug() << "load success:" <<*/ translator.load(fname, QString::fromUtf8(TRANSLATIONS_DIR), QStringLiteral("_"));
+    installTr = translator.load(fname, QString::fromUtf8(TRANSLATIONS_DIR), QStringLiteral("_"));
 #endif
 #ifdef APPLE_BUNDLE
     QDir translations_dir = QDir(QApplication::applicationDirPath());
     translations_dir.cdUp();
     if (translations_dir.cd(QStringLiteral("Resources/translations"))) {
-        //qDebug() << "APPLE_BUNDLE: Loading translator file" << fname << "from dir" << translations_dir.path();
-        /*qDebug() << "load success:" <<*/ translator.load(fname, translations_dir.path(), QStringLiteral("_"));
+        installTr = translator.load(fname, translations_dir.path(), QStringLiteral("_"));
     } /*else {
         qWarning() << "Unable to find \"Resources/translations\" dir in" << translations_dir.path();
     }*/
 #endif
-    app->installTranslator(&translator);
+    if (installTr)
+    {
+        app->installTranslator(&translator);
+    }
 
     TerminalConfig initConfig = TerminalConfig(workdir, shell_command);
     app->newWindow(dropMode, initConfig);
@@ -277,7 +292,7 @@ QList<MainWindow *> QTerminalApp::getWindowList()
 }
 
 #ifdef HAVE_QDBUS
-void QTerminalApp::registerOnDbus()
+void QTerminalApp::registerOnDbus(bool dropDown)
 {
     if (!QDBusConnection::sessionBus().isConnected())
     {
@@ -286,20 +301,34 @@ void QTerminalApp::registerOnDbus()
                 "\teval `dbus-launch --auto-syntax`\n");
         return;
     }
-    QString serviceName = QStringLiteral("org.lxqt.QTerminal-%1").arg(getpid());
-    if (!QDBusConnection::sessionBus().registerService(serviceName))
+
+    if (dropDown)
     {
-        fprintf(stderr, "%s\n", qPrintable(QDBusConnection::sessionBus().lastError().message()));
-        return;
+        if (!QDBusConnection::sessionBus().registerService(QLatin1String(serviceName)))
+        {
+            m_isPrimaryInstance = false;
+            return;
+        }
+        new ProcessAdaptor(this);
+        QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this);
+    }
+    else
+    {
+        if (!QDBusConnection::sessionBus().registerService(QLatin1String(serviceName)
+                                                           + QStringLiteral("-%1").arg(getpid())))
+        {
+            fprintf(stderr, "%s\n", qPrintable(QDBusConnection::sessionBus().lastError().message()));
+            return;
+        }
+        new ProcessAdaptor(this);
+        QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this);
     }
-    new ProcessAdaptor(this);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this);
 }
 
 QList<QDBusObjectPath> QTerminalApp::getWindows()
 {
     QList<QDBusObjectPath> windows;
-    for (MainWindow *wnd : qAsConst(m_windowList))
+    for (MainWindow *wnd : std::as_const(m_windowList))
     {
         windows.push_back(wnd->getDbusPath());
     }
@@ -342,6 +371,18 @@ bool QTerminalApp::toggleDropdown() {
   return true;
 }
 
+void QTerminalApp::requestDropDown()
+{
+    QDBusInterface iface(QLatin1String(serviceName),
+                         QStringLiteral("/"),
+                         QLatin1String(ifaceName), QDBusConnection::sessionBus(), this);
+    iface.call(QStringLiteral("toggleDropdown"));
+}
+
+bool QTerminalApp::isPrimaryInstance() {
+  return m_isPrimaryInstance;
+}
+
 
 #endif
 
