@@ -291,10 +291,10 @@ void MainWindow::setup_ActionsMenu_Actions()
 
     menu_Actions->addSeparator();
 
-    setup_Action(SPLIT_HORIZONTAL, new QAction(tr("Split Terminal &Horizontally"), settingOwner),
+    setup_Action(SPLIT_HORIZONTAL, new QAction(tr("Split &View Top-Bottom"), settingOwner),
                  nullptr, consoleTabulator, SLOT(splitHorizontally()), menu_Actions);
 
-    setup_Action(SPLIT_VERTICAL, new QAction(tr("Split Terminal &Vertically"), settingOwner),
+    setup_Action(SPLIT_VERTICAL, new QAction(tr("Split Vie&w Left-Right"), settingOwner),
                  nullptr, consoleTabulator, SLOT(splitVertically()), menu_Actions);
 
     data.setValue(checkSubterminals);
@@ -381,8 +381,10 @@ void MainWindow::setup_FileMenu_Actions()
 
     if (presetsMenu == nullptr) {
         presetsMenu = new QMenu(tr("New Tab From &Preset"), this);
-        presetsMenu->addAction(QIcon(), tr("1 &Terminal"),
-                               this, SLOT(addNewTab()));
+        auto a = presetsMenu->addAction(QIcon(), tr("1 &Terminal"));
+        connect(a, &QAction::triggered, consoleTabulator, [this]() {
+            consoleTabulator->addNewTab(m_config);
+        });
         presetsMenu->addAction(QIcon(), tr("2 &Horizontal Terminals"),
                                consoleTabulator, SLOT(preset2Horizontal()));
         presetsMenu->addAction(QIcon(), tr("2 &Vertical Terminals"),
@@ -633,6 +635,7 @@ void MainWindow::closeEvent(QCloseEvent *ev)
             Properties::Instance()->windowMaximized = isMaximized();
             Properties::Instance()->mainWindowState = saveState();
         }
+        rebuildActions(); // shortcuts may have changed by another running instance
         Properties::Instance()->saveSettings();
         for (int i = consoleTabulator->count(); i > 0; --i) {
             consoleTabulator->removeTab(i - 1);
@@ -667,6 +670,7 @@ void MainWindow::closeEvent(QCloseEvent *ev)
         Properties::Instance()->mainWindowState = saveState();
         Properties::Instance()->askOnExit = !dontAskCheck->isChecked();
         Properties::Instance()->windowMaximized = isMaximized();
+        rebuildActions();
         Properties::Instance()->saveSettings();
         for (int i = consoleTabulator->count(); i > 0; --i) {
             consoleTabulator->removeTab(i - 1);
@@ -874,8 +878,22 @@ void MainWindow::newTerminalWindow()
     if (ch)
         cfg.provideCurrentDirectory(ch->currentTerminal()->impl()->workingDirectory());
 
-    MainWindow *w = new MainWindow(cfg, false);
-    w->show();
+    if (m_dropMode)
+    { // the dropdown process has only one (dropdown) main window
+        QStringList args;
+        args <<  QStringLiteral("-w") << cfg.getWorkingDirectory();
+        QString profile = Properties::Instance()->profile();
+        if (!profile.isEmpty())
+        {
+            args << QStringLiteral("-p") << profile;
+        }
+        QProcess::startDetached(QStringLiteral("qterminal"), args);
+    }
+    else
+    {
+        MainWindow *w = new MainWindow(cfg, false);
+        w->show();
+    }
 }
 
 void MainWindow::bookmarksWidget_callCommand(const QString& cmd)
