@@ -42,6 +42,18 @@ Properties::Properties(const QString& filename)
     else
         m_settings = new QSettings(filename);
     //qDebug("Properties constructor called");
+
+    m_watcher = new QFileSystemWatcher();
+    m_watcher->addPath(m_settings->fileName());
+    QObject::connect(m_watcher, &QFileSystemWatcher::fileChanged, [this](const QString &path) {
+        if (m_settings)
+        {
+            m_settings->sync();
+            loadSettings();
+            if (!m_watcher->files().contains(path))
+                m_watcher->addPath(path);
+        }
+    });
 }
 
 Properties::~Properties()
@@ -49,6 +61,8 @@ Properties::~Properties()
     //qDebug("Properties destructor called");
     delete m_settings;
     m_instance = nullptr;
+    delete  m_watcher;
+    m_watcher = nullptr;
 }
 
 QFont Properties::defaultFont()
@@ -161,6 +175,7 @@ void Properties::loadSettings()
 
     confirmMultilinePaste = m_settings->value(QLatin1String("ConfirmMultilinePaste"), false).toBool();
     trimPastedTrailingNewlines = m_settings->value(QLatin1String("TrimPastedTrailingNewlines"), false).toBool();
+    wordCharacters = m_settings->value(QLatin1String("WordCharacters"), QLatin1String(":@-./_~")).toString();
 
     windowMaximized = m_settings->value(QLatin1String("LastWindowMaximized"), false).toBool();
 
@@ -273,11 +288,19 @@ void Properties::saveSettings()
 
     m_settings->setValue(QLatin1String("ConfirmMultilinePaste"), confirmMultilinePaste);
     m_settings->setValue(QLatin1String("TrimPastedTrailingNewlines"), trimPastedTrailingNewlines);
+    m_settings->setValue(QLatin1String("WordCharacters"), wordCharacters);
 
     m_settings->setValue(QLatin1String("LastWindowMaximized"), windowMaximized);
     m_settings->setValue(QLatin1String("SwapMouseButtons2and3"), swapMouseButtons2and3);
 
     m_settings->setValue(QLatin1String("PrefDialogSize"), prefDialogSize);
+
+    // the config file may be created now
+    if (!m_watcher->files().contains(m_settings->fileName()))
+    {
+        m_settings->sync();
+        m_watcher->addPath(m_settings->fileName());
+    }
 }
 
 int Properties::versionComparison(const QString &v1, const QString &v2)
@@ -393,3 +416,8 @@ QString Properties::configDir() const
     return QFileInfo(m_settings->fileName()).absoluteDir().canonicalPath();
 }
 
+QString Properties::profile() const
+{
+    return filename;
+}
+
