@@ -22,6 +22,7 @@
 #include <QApplication>
 #include <QtCore>
 #include <QFont>
+#include <QFileSystemWatcher>
 
 typedef QString Session;
 
@@ -41,6 +42,7 @@ class Properties
         void loadSettings();
         void migrate_settings();
         QString configDir() const;
+        QString profile() const;
 
         static void removeAccelerator(QString& str);
 
@@ -143,6 +145,7 @@ class Properties
 
         QSettings *m_settings;
 
+        QFileSystemWatcher *m_watcher;
 };
 
 #endif
