@@ -8,15 +8,13 @@
 #include "properties.h"
 #include "termwidget.h"
 
-TerminalConfig::TerminalConfig(const QString & wdir, const QStringList & shell)
+TerminalConfig::TerminalConfig(const QString &wdir, const QStringList &shell)
+    : m_workingDirectory(wdir)
+    , m_shell(shell)
 {
-    m_workingDirectory = wdir;
-    m_shell = shell;
 }
 
-TerminalConfig::TerminalConfig()
-{
-}
+TerminalConfig::TerminalConfig() = default;
 
 TerminalConfig::TerminalConfig(const TerminalConfig &cfg)
     : m_currentDirectory(cfg.m_currentDirectory),
@@ -82,14 +80,14 @@ TerminalConfig TerminalConfig::fromDbus(const QHash<QString,QVariant> &termArgsC
 
 static QString variantToString(const QVariant& variant, QString &defaultVal)
 {
-    if (variant.type() == QVariant::String)
+    if (variant.typeId() == QMetaType::QString)
         return qvariant_cast<QString>(variant);
     return defaultVal;
 }
 
 static QStringList variantToStringList(const QVariant& variant, QStringList &defaultVal)
 {
-    if (variant.type() == QVariant::StringList)
+    if (variant.typeId() == QMetaType::QStringList)
         return qvariant_cast<QStringList>(variant);
     return defaultVal;
 }
