@@ -11,15 +11,15 @@ class TermWidget;
 class TerminalConfig
 {
     public:
-        TerminalConfig(const QString & wdir, const QString & shell);
+        TerminalConfig(const QString & wdir, const QStringList & shell);
         TerminalConfig(const TerminalConfig &cfg);
         TerminalConfig();
 
         QString getWorkingDirectory();
-        QString getShell();
+        QStringList getShell();
 
         void setWorkingDirectory(const QString &val);
-        void setShell(const QString &val);
+        void setShell(const QStringList &val);
         void provideCurrentDirectory(const QString &val);
 
         #ifdef HAVE_QDBUS
@@ -29,10 +29,10 @@ class TerminalConfig
 
 
     private:
-    	// True when 
+    	// True when
     	QString m_currentDirectory;
     	QString m_workingDirectory;
-        QString m_shell;
+        QStringList m_shell;
 };
 
-#endif
\ No newline at end of file
+#endif
