@@ -61,9 +61,7 @@ TermWidgetHolder::TermWidgetHolder(TerminalConfig &config, QWidget * parent)
     setLayout(lay);
 }
 
-TermWidgetHolder::~TermWidgetHolder()
-{
-}
+TermWidgetHolder::~TermWidgetHolder() = default;
 
 void TermWidgetHolder::setInitialFocus()
 {
@@ -75,7 +73,7 @@ void TermWidgetHolder::setInitialFocus()
 
 void TermWidgetHolder::loadSession()
 {
-    bool ok;
+    bool ok = false;
     QString name = QInputDialog::getItem(this, tr("Load Session"),
                                          tr("List of saved sessions:"),
                                          Properties::Instance()->sessions.keys(),
@@ -201,7 +199,7 @@ void TermWidgetHolder::directionalNavigation(NavigationDirection dir) {
     // Find an active widget
     QList<TermWidget*> l = findChildren<TermWidget*>();
     int ix = -1;
-    for (TermWidget * w : qAsConst(l))
+    for (TermWidget * w : std::as_const(l))
     {
         ++ix;
         if (w->impl()->hasFocus())
@@ -233,7 +231,7 @@ void TermWidgetHolder::directionalNavigation(NavigationDirection dir) {
     int lowestX = INT_MAX;
     int lowestMidpointDistance = INT_MAX;
     TermWidget *fittest = nullptr;
-    for (TermWidget * w : qAsConst(l))
+    for (TermWidget * w : std::as_const(l))
     {
         NavigationData contenderDims = getNormalizedDimensions(w, dir);
         int midpointDistance = std::min(
